# Open Asset Model in Python 

[![PyPI version](https://badge.fury.io/py/open-asset-model.svg)](https://badge.fury.io/py/open-asset-model)
![Python version](https://img.shields.io/badge/python-%3E%3D3.10-blue)

This package is a Python implementation of the
[Open Asset Model](https://github.com/owasp-amass/open-asset-model),
originally developed in Go as part of
[OWASP Amass Project](https://owasp.org/www-project-amass/).

## Open Asset Model

The Open Asset Model is a specification that defines a data model
for attack surface intelligence. It describes entities
and relationship covering both infrastructural and organizational assets, 
represented within a Labeled Property Graph (LPG).

## Install

```bash
pip install open-asset-model
```

## License

This code is licensed under the Apache License version 2.0.

See the LICENSE file for details.
